@@ -294,7 +294,7 @@ typedef struct {
 } WifiMenuItemInfo;
 
 static void
-wifi_menu_item_info_destroy (gpointer data, GClosure *closure)
+wifi_menu_item_info_destroy (gpointer data)
 {
 	WifiMenuItemInfo *info = (WifiMenuItemInfo *) data;
 
@@ -645,14 +645,14 @@ create_new_ap_item (NMDeviceWifi *device,
 
 			info = g_slice_new0 (WifiMenuItemInfo);
 			info->applet = applet;
-			info->device = g_object_ref (device);
-			info->ap = g_object_ref (ap);
-			info->connection = g_object_ref (connection);
+			info->device = g_object_ref (G_OBJECT (device));
+			info->ap = g_object_ref (G_OBJECT (ap));
+			info->connection = g_object_ref (G_OBJECT (connection));
 
 			g_signal_connect_data (subitem, "activate",
 			                       G_CALLBACK (wifi_menu_item_activate),
 			                       info,
-			                       wifi_menu_item_info_destroy, 0);
+			                       (GClosureNotify) wifi_menu_item_info_destroy, 0);
 
 			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), GTK_WIDGET (subitem));
 		}
@@ -663,8 +663,8 @@ create_new_ap_item (NMDeviceWifi *device,
 
 		info = g_slice_new0 (WifiMenuItemInfo);
 		info->applet = applet;
-		info->device = g_object_ref (device);
-		info->ap = g_object_ref (ap);
+		info->device = g_object_ref (G_OBJECT (device));
+		info->ap = g_object_ref (G_OBJECT (ap));
 
 		if (ap_connections->len == 1) {
 			connection = NM_CONNECTION (ap_connections->pdata[0]);
@@ -675,7 +675,7 @@ create_new_ap_item (NMDeviceWifi *device,
 		                       "activate",
 		                       G_CALLBACK (wifi_menu_item_activate),
 		                       info,
-		                       wifi_menu_item_info_destroy,
+		                       (GClosureNotify) wifi_menu_item_info_destroy,
 		                       0);
 	}
 
@@ -1082,10 +1082,15 @@ idle_check_avail_access_point_notification (gpointer datap)
 	aps = nm_device_wifi_get_access_points (device);
 	for (i = 0; i < aps->len; i++) {
 		NMAccessPoint *ap = aps->pdata[i];
-		GPtrArray *ap_connections = nm_access_point_filter_connections (ap, connections);
+		GPtrArray *ap_connections;
 		int a;
 		gboolean is_autoconnect = FALSE;
 
+		if (!nm_access_point_get_ssid (ap))
+			continue;
+
+		ap_connections = nm_access_point_filter_connections (ap, connections);
+
 		for (a = 0; a < ap_connections->len; a++) {
 			NMConnection *connection = NM_CONNECTION (ap_connections->pdata[a]);
 			NMSettingConnection *s_con;
