@@ -35,6 +35,7 @@
 struct _EAPMethodTTLS {
 	EAPMethod parent;
 
+	const char *password_flags_name;
 	GtkSizeGroup *size_group;
 	WirelessSecurity *sec_parent;
 	gboolean is_editor;
@@ -130,7 +131,7 @@ add_to_size_group (EAPMethod *parent, GtkSizeGroup *group)
 }
 
 static void
-fill_connection (EAPMethod *parent, NMConnection *connection, NMSettingSecretFlags flags)
+fill_connection (EAPMethod *parent, NMConnection *connection)
 {
 	NMSetting8021x *s_8021x;
 	NMSetting8021xCKFormat format = NM_SETTING_802_1X_CK_FORMAT_UNKNOWN;
@@ -171,7 +172,7 @@ fill_connection (EAPMethod *parent, NMConnection *connection, NMSettingSecretFla
 	gtk_tree_model_get (model, &iter, I_METHOD_COLUMN, &eap, -1);
 	g_assert (eap);
 
-	eap_method_fill_connection (eap, connection, flags);
+	eap_method_fill_connection (eap, connection);
 	eap_method_unref (eap);
 }
 
@@ -227,6 +228,7 @@ inner_auth_combo_init (EAPMethodTTLS *method,
 	EAPMethodSimple *em_pap;
 	EAPMethodSimple *em_mschap;
 	EAPMethodSimple *em_mschap_v2;
+	EAPMethodSimple *em_plain_mschap_v2;
 	EAPMethodSimple *em_chap;
 	EAPMethodSimple *em_md5;
 	EAPMethodSimple *em_gtc;
@@ -291,9 +293,26 @@ inner_auth_combo_init (EAPMethodTTLS *method,
 	eap_method_unref (EAP_METHOD (em_mschap_v2));
 
 	/* Check for defaulting to MSCHAPv2 */
-	if (phase2_auth && !strcasecmp (phase2_auth, "mschapv2"))
+	if (phase2_auth && !strcasecmp (phase2_auth, "mschapv2") &&
+	    nm_setting_802_1x_get_phase2_autheap (s_8021x) != NULL)
 		active = 2;
 
+	em_plain_mschap_v2 = eap_method_simple_new (method->sec_parent,
+	                                            connection,
+	                                            EAP_METHOD_SIMPLE_TYPE_PLAIN_MSCHAP_V2,
+	                                            simple_flags);
+	gtk_list_store_append (auth_model, &iter);
+	gtk_list_store_set (auth_model, &iter,
+	                    I_NAME_COLUMN, _("MSCHAPv2 (no EAP)"),
+	                    I_METHOD_COLUMN, em_plain_mschap_v2,
+	                    -1);
+	eap_method_unref (EAP_METHOD (em_plain_mschap_v2));
+
+	/* Check for defaulting to plain MSCHAPv2 */
+	if (phase2_auth && !strcasecmp (phase2_auth, "mschapv2") &&
+	    nm_setting_802_1x_get_phase2_auth (s_8021x) != NULL)
+		active = 3;
+
 	em_chap = eap_method_simple_new (method->sec_parent,
 	                                 connection,
 	                                 EAP_METHOD_SIMPLE_TYPE_CHAP,
@@ -307,7 +326,7 @@ inner_auth_combo_init (EAPMethodTTLS *method,
 
 	/* Check for defaulting to CHAP */
 	if (phase2_auth && !strcasecmp (phase2_auth, "chap"))
-		active = 3;
+		active = 4;
 
 	em_md5 = eap_method_simple_new (method->sec_parent,
 	                                connection,
@@ -322,7 +341,7 @@ inner_auth_combo_init (EAPMethodTTLS *method,
 
 	/* Check for defaulting to MD5 */
 	if (phase2_auth && !strcasecmp (phase2_auth, "md5"))
-		active = 4;
+		active = 5;
 
 	em_gtc = eap_method_simple_new (method->sec_parent,
 	                                connection,
@@ -337,7 +356,7 @@ inner_auth_combo_init (EAPMethodTTLS *method,
 
 	/* Check for defaulting to GTC */
 	if (phase2_auth && !strcasecmp (phase2_auth, "gtc"))
-		active = 5;
+		active = 6;
 
 	combo = GTK_WIDGET (gtk_builder_get_object (parent->builder, "eap_ttls_inner_auth_combo"));
 	g_assert (combo);
@@ -380,15 +399,15 @@ eap_method_ttls_new (WirelessSecurity *ws_parent,
 	                          fill_connection,
 	                          update_secrets,
 	                          destroy,
-	                          UIDIR "/eap-method-ttls.ui",
+	                          "/org/freedesktop/network-manager-applet/eap-method-ttls.ui",
 	                          "eap_ttls_notebook",
 	                          "eap_ttls_anon_identity_entry",
 	                          FALSE);
 	if (!parent)
 		return NULL;
 
-	parent->password_flags_name = NM_SETTING_802_1X_PASSWORD;
 	method = (EAPMethodTTLS *) parent;
+	method->password_flags_name = NM_SETTING_802_1X_PASSWORD;
 	method->sec_parent = ws_parent;
 	method->is_editor = is_editor;
 
